@@ -28,18 +28,14 @@ el.test1 <- function(x, mu, R = 1, ncores = 1, graph = FALSE) {
       runtime <- proc.time()
       cl <- makePSOCKcluster(ncores)
       registerDoParallel(cl) ## make the cluster
-
-      ww <- foreach( i = 1:R, .combine = cbind, .packages = "emplik",
+      tb <- foreach( i = 1:R, .combine = rbind, .packages = "emplik",
         .export = "el.test" ) %dopar% {
          b <- sample(1:n, n, replace = TRUE)
-         tb[i] <- emplik::el.test(y[b, ], mu, maxit = 1000)$"-2LLR"
+         ww <- emplik::el.test(y[b, ], mu, maxit = 1000)$"-2LLR"
      }
-
       stopCluster(cl) ## stop the cluster
-      tb <- as.vector(ww)
       runtime <- proc.time() - runtime
     }
-
     pvalue <- ( sum(tb > stat) + 1 ) / (R + 1)
     res <- list(res = res, boot.pvalue = pvalue, runtime = runtime)
   }
